@@ -25,9 +25,9 @@ if CONFIG.debug:  # pragma: no cover
 
 
 app = FastAPI(
-    title="OPTiMaDe API",
+    title="OPTIMADE API",
     description=(
-        f"""The [Open Databases Integration for Materials Design (OPTiMaDe) consortium](https://www.optimade.org/) aims to make materials databases interoperational by developing a common REST API.
+        f"""The [Open Databases Integration for Materials Design (OPTIMADE) consortium](https://www.optimade.org/) aims to make materials databases interoperational by developing a common REST API.
 
 This specification is generated using [`optimade-python-tools`](https://github.com/Materials-Consortia/optimade-python-tools/tree/v{__version__}) v{__version__}."""
     ),
@@ -70,6 +70,7 @@ app.add_exception_handler(
 )
 app.add_exception_handler(ValidationError, exc_handlers.validation_exception_handler)
 app.add_exception_handler(VisitError, exc_handlers.grammar_not_implemented_handler)
+app.add_exception_handler(NotImplementedError, exc_handlers.not_implemented_handler)
 app.add_exception_handler(Exception, exc_handlers.general_exception_handler)
 
 
